:orphan:

*****************
`Workshift` class
*****************


.. autoclass:: timeboard.Workshift
   :members: to_timestamp, is_on_duty, is_off_duty, worktime, 
             rollforward, rollback, __add__, __sub__